diff --git a/libavcodec/av1dec.c b/libavcodec/av1dec.c
index 11dad4d33f..a71640eb0d 100644
--- a/libavcodec/av1dec.c
+++ b/libavcodec/av1dec.c
@@ -798,6 +798,7 @@ static av_cold int av1_decode_init(AVCodecContext *avctx)
 
     s->avctx = avctx;
     s->pix_fmt = AV_PIX_FMT_NONE;
+    s->export_side_data = avctx->export_side_data;
 
     for (int i = 0; i < FF_ARRAY_ELEMS(s->ref); i++) {
         s->ref[i].f = av_frame_alloc();
@@ -975,7 +976,7 @@ static int set_output_frame(AVCodecContext *avctx, AVFrame *frame,
     if (ret < 0)
         return ret;
 
-    if (avctx->export_side_data & AV_CODEC_EXPORT_DATA_FILM_GRAIN) {
+    if (s->export_side_data & AV_CODEC_EXPORT_DATA_FILM_GRAIN) {
         ret = export_film_grain(avctx, frame);
         if (ret < 0) {
             av_frame_unref(frame);
diff --git a/libavcodec/av1dec.h b/libavcodec/av1dec.h
index d6ccf040ea..818062b5a3 100644
--- a/libavcodec/av1dec.h
+++ b/libavcodec/av1dec.h
@@ -81,6 +81,7 @@ typedef struct AV1DecContext {
     uint16_t tg_end;
 
     int operating_point_idc;
+    int export_side_data;
 
     AV1Frame ref[AV1_NUM_REF_FRAMES];
     AV1Frame cur_frame;
diff --git a/libavcodec/vulkan_decode.c b/libavcodec/vulkan_decode.c
index 58906a1bc2..6bff4d0666 100644
--- a/libavcodec/vulkan_decode.c
+++ b/libavcodec/vulkan_decode.c
@@ -19,6 +19,7 @@
 #include "vulkan_video.h"
 #include "vulkan_decode.h"
 #include "config_components.h"
+#include "av1dec.h"
 
 #if CONFIG_H264_VULKAN_HWACCEL
 extern const VkExtensionProperties ff_vk_dec_h264_ext;
@@ -868,6 +869,12 @@ repeat:
         ctx->dedicated_dpb = dedicated_dpb;
         ctx->layered_dpb = layered_dpb;
         ctx->init = 1;
+
+        if (avctx->codec_id == AV_CODEC_ID_AV1 &&
+            av1_caps.flags & VK_VIDEO_DECODE_AV1_CAPABILITIES_EXTERNAL_FILM_GRAIN_MESA) {
+            AV1DecContext *av1_ctx = avctx->priv_data;
+            av1_ctx->export_side_data |= AV_CODEC_EXPORT_DATA_FILM_GRAIN;
+        }
     }
 
     *pix_fmt = AV_PIX_FMT_NONE;
diff --git a/libavcodec/vulkan_video_codec_av1std.h b/libavcodec/vulkan_video_codec_av1std.h
index 504ca266b0..841df89fa8 100644
--- a/libavcodec/vulkan_video_codec_av1std.h
+++ b/libavcodec/vulkan_video_codec_av1std.h
@@ -381,9 +381,14 @@ typedef struct VkVideoDecodeAV1ProfileInfoMESA {
     StdVideoAV1MESAProfile stdProfileIdc;
 } VkVideoDecodeAV1ProfileInfoMESA;
 
+typedef enum VkVideoDecodeAV1CapabilitiesMESAFlagBits {
+    VK_VIDEO_DECODE_AV1_CAPABILITIES_EXTERNAL_FILM_GRAIN_MESA = 0x00000001,
+} VkVideoDecodeAV1CapabilitiesMESAFlagBits;
+
 typedef struct VkVideoDecodeAV1CapabilitiesMESA {
     VkStructureType sType;
     const void *pNext;
+    VkVideoDecodeAV1CapabilitiesMESAFlagBits flags;
     StdVideoAV1MESALevel maxLevelIdc;
 } VkVideoDecodeAV1CapabilitiesMESA;
 
